#include "util/configyyrename.h"

#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 33
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	(yytext_ptr) -= (yy_more_len); \
	yyleng = (size_t) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 86
#define YY_END_OF_BUFFER 87
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[732] =
    {   0,
        1,    1,   70,   70,   74,   74,   78,   78,   82,   82,
       87,   85,    1,   68,   69,    2,   73,   86,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   70,   71,   86,   72,   86,
       74,   75,   76,   86,   81,   78,   79,   80,   86,   82,
       83,   84,   86,   85,    0,    1,    2,    2,    2,    2,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   70,    0,
       74,    0,   81,    0,   78,   82,    0,   85,   85,   85,

       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   41,   85,   85,
       85,   85,    6,   85,   85,   85,   85,   85,   85,   85,

       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   17,   85,   11,   12,
       85,   14,   13,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,    3,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,

       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   77,   85,   85,   85,   85,
       85,   85,   85,   85,   20,   85,   85,   85,   85,   85,
       85,   21,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   53,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   52,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   18,   85,   85,   85,
       85,   85,   85,   85,   85,   19,   85,   85,   85,   85,

       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       15,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   42,   43,   40,   85,   85,
       85,   85,   85,   85,   85,   85,   85,    5,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   67,   66,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   22,   85,   85,   85,
       85,   65,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   38,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,

        4,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   45,   46,   44,
       85,   85,   85,   85,   51,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   57,   85,   85,   85,   85,
       85,   85,   85,   28,   85,   85,   85,   85,   85,   50,
       85,   85,   85,   85,   85,   85,   85,   85,   54,   85,
       85,   85,   85,   85,   85,    7,   85,   85,   85,   85,
       85,   85,   59,   85,   85,   85,   85,   49,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   29,   30,   62,

       85,   85,   24,   85,   85,   85,   85,    8,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   63,   23,   25,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   10,   85,   85,   85,
       85,   85,    9,   26,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   31,
       85,   85,   27,   85,   55,   56,   85,   85,   58,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   16,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,

       85,   35,   85,   85,   61,   47,   85,   85,   37,   36,
       85,   32,   85,   60,   85,   85,   85,   33,   85,   85,
       48,   39,   34,   85,   85,   85,   85,   85,   85,   64,
        0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    7,    1,
        1,    1,    1,    1,    8,    1,    1,    1,    1,    1,
        9,   10,    1,   11,    1,    1,    1,   12,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,   13,    1,    1,    1,    1,   14,   15,   16,   17,

       18,   19,   20,   21,   22,    1,   23,   24,   25,   26,
       27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
       37,   38,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[39] =
    {   0,
        1,    2,    3,    4,    5,    1,    6,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[743] =
    {   0,
        0,    0,   36,   39,   43,   50,   62,   74,   55,   67,
     1513, 1499,   49, 1514, 1514,   81, 1514,   88,   32,   83,
       76,   78,   60,   89,   94,   86,   87,   95,   88,   97,
      103,  104,  112,   98,  121, 1498, 1514, 1514, 1514,   57,
     1497, 1514, 1514,  116, 1496, 1506, 1514, 1514,  136, 1494,
     1514, 1514,  127, 1493,  142,  146,    0,  149,    0,    0,
      142,  144,  137,  146,  153,  150,  151,  152,  155,  158,
      157,  159,  165,  171,  170,  172,  173,  175,  174,  176,
      114,  180,  183,  185,  186,  188,  187,  194, 1492,  204,
     1491,  210, 1490,  216, 1500, 1488,  208,  209,  212,  213,

      216,  215,  217,  218,  225,  219,  226,  229,  231,  238,
      241,  243,  244,  250,  247,  253,  251,  254,  255,  256,
      257,  259,  261,  265,  266,  273,  276,  267,  270,  277,
      278,  283,  279,  281,  293,  287,  297,  299,  305,  289,
      301,  302,  306,  303,  309,  311,  310,  313,  315,  326,
      316,  323,  327,  329,  338,  330,  334,  345,  341,  331,
      342,  343,  361,  344,  348,  347,  359,  351,  352,  369,
      353,  362,  368,  373,  378,  379,  380,  381,  384,  387,
      386,  394,  401,  397,  398,  399,  404, 1487,  402,  406,
      407,  409, 1486,  410,  417,  411,  423,  413,  430,  415,

      426,  429,  433,  434,  421,  436,  437,  440,  450,  446,
      457,  447,  460,  463,  469,  466,  468,  449,  475,  472,
      473,  471,  474,  438,  477,  481,  483,  487,  484,  497,
      493,  495,  496,  494,  500,  502,  505,  503,  509,  515,
      504,  510,  521,  522,  525,  517,  520,  526,  531,  534,
      537,  527,  538,  528,  540,  545, 1485,  548, 1484, 1483,
      550, 1482, 1481,  554,  551,  552,  553,  556,  560,  561,
      563,  567,  571,  573,  574,  577,  575,  584,  585,  586,
      579,  590,  591,  593,  595,  597,  598, 1480,  601,  602,
      603,  606,  604,  613,  611,  609,  615,  618,  621,  623,

      625,  626,  628,  629,  630,  631,  632,  633,  636,  639,
      646,  648,  638,  642,  662, 1479,  659,  663,  657,  664,
      665,  667,  668,  669, 1478,  671,  673,  674,  677,  680,
      688, 1477,  684,  689,  690,  691,  693,  694,  697,  695,
      701,  709,  696,  704,  706,  711,  712,  713, 1476,  716,
      723,  720,  722,  726,  724,  725,  731,  732,  733,  734,
      735,  736, 1475,  740,  743,  741,  742,  756,  762,  758,
      761,  763,  764,  770,  767,  769,  771,  774,  775,  778,
      790,  794,  768,  791,  795,  796, 1474,  802,  806,  809,
      798,  805,  811,  808,  812, 1473,  813,  814,  815,  816,

      817,  819,  821,  820,  825,  822,  826,  838,  844,  845,
     1472,  832,  842,  848,  779,  854,  851,  852,  853,  855,
      856,  858,  859,  862,  873, 1471, 1470, 1469,  863,  865,
      857,  875,  864,  884,  867,  882,  880, 1468,  887,  888,
      889,  891,  890,  892,  894,  896,  900,  893,  901,  902,
      906,  916,  903,  910,  914, 1467, 1466,  917,  919,  921,
      933,  935,  924,  927,  931,  936, 1465,  945,  938,  941,
      942, 1464,  944,  947,  950,  952,  953,  954,  956,  964,
      966,  970,  972,  973, 1463,  979,  980,  961,  978,  986,
      982,  983,  984,  987,  988,  990,  992,  991,  998,  994,

     1462, 1005, 1011,  996, 1007, 1004, 1013, 1024, 1025, 1017,
     1026, 1018, 1032, 1029, 1033, 1035, 1036, 1461, 1460, 1459,
     1043, 1039,  744, 1041, 1458, 1045, 1048, 1031, 1046, 1052,
     1054, 1053, 1059, 1067, 1056, 1068, 1060, 1069, 1070, 1071,
     1076, 1072, 1080, 1078, 1079, 1457, 1082, 1084, 1086, 1092,
     1094, 1096, 1100, 1456, 1102, 1097, 1103, 1104, 1105, 1455,
     1109, 1107, 1108, 1113, 1116, 1118, 1123, 1126, 1454, 1127,
     1129, 1130, 1133, 1131, 1135, 1453, 1140, 1134, 1141, 1143,
     1136, 1146, 1452, 1147, 1149, 1151, 1161, 1451, 1160, 1162,
     1153, 1163, 1167, 1154, 1170, 1171, 1174, 1447, 1443, 1442,

     1178, 1181, 1441, 1183, 1189, 1185, 1187, 1437, 1188, 1190,
     1194, 1195, 1196, 1191, 1197, 1198, 1199, 1201, 1203, 1208,
     1209, 1210, 1213, 1219, 1215, 1216, 1436, 1432, 1431, 1220,
     1221, 1231, 1233, 1223, 1227, 1235, 1237, 1238, 1243, 1244,
     1245, 1246, 1247, 1253, 1254, 1255, 1430, 1250, 1256, 1261,
     1257, 1266, 1424, 1396, 1270, 1272, 1277, 1279, 1267, 1286,
     1283, 1284, 1273, 1285, 1287, 1289, 1290, 1292, 1295, 1395,
     1296, 1298, 1394, 1299, 1393, 1392, 1303, 1300, 1390, 1305,
     1306, 1307, 1311, 1312, 1317, 1308, 1316, 1320, 1389, 1319,
     1327, 1328, 1332, 1336, 1337, 1339, 1341, 1343, 1345, 1349,

     1351, 1388, 1354, 1356, 1387, 1385, 1346, 1358, 1384, 1329,
     1360, 1021, 1363,  782, 1357, 1369, 1371,  644, 1373, 1375,
      530,  355,  223, 1364, 1377, 1366, 1378, 1379, 1382,  189,
     1514, 1410, 1416, 1422, 1428,  136, 1434, 1440, 1446,   83,
     1451, 1457
    } ;

static yyconst flex_int16_t yy_def[743] =
    {   0,
      731,    1,  732,  732,  733,  733,  734,  734,  735,  735,
      731,  736,  731,  731,  731,  737,  731,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  738,  731,  731,  731,  738,
      739,  731,  731,  739,  740,  731,  731,  731,  740,  741,
      731,  731,  741,  736,  736,  731,  742,  737,  742,  737,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  738,  738,
      739,  739,  740,  740,  731,  741,  741,  736,  736,  736,

      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,

      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,

      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,

      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,

      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,

      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,

      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  736,
        0,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731
    } ;

static yyconst flex_int16_t yy_nxt[1553] =
    {   0,
       12,   13,   14,   14,   15,   16,   17,   12,   12,   12,
       12,   12,   18,   19,   12,   20,   21,   12,   22,   12,
       23,   24,   25,   26,   27,   28,   29,   30,   12,   31,
       32,   33,   34,   35,   12,   12,   12,   12,   37,   38,
       39,   37,   38,   39,   55,   42,   38,   61,   40,   43,
       56,   40,   42,   38,   57,   44,   43,   51,   51,   52,
       89,   89,   44,   46,   47,   47,   48,   53,   38,   51,
       51,   52,   55,   67,   49,   46,   47,   47,   48,   53,
       38,   68,   59,   93,   59,   59,   49,   59,   55,   54,
       55,   54,   54,   60,   54,   55,   62,   64,   55,   55,

       55,   55,   65,   63,   66,   69,   55,   55,   75,   55,
       55,   71,   72,   73,   70,   55,   55,   74,   78,   91,
       77,   82,   91,   79,   55,   84,   55,   76,   86,   80,
       96,   96,   81,   55,   87,   83,   54,   93,   88,   93,
       93,   85,   93,   54,  121,   54,   54,   56,   54,   55,
       59,   57,   59,   59,   55,   59,   55,   98,   55,   99,
      102,   60,   55,   55,   55,   55,  100,   55,  105,   55,
       55,   55,  106,  107,  111,  101,  108,   55,  112,  103,
      104,  113,   55,   55,   55,   55,   55,   55,   55,  109,
      114,  118,   55,  110,  115,   55,  116,   55,   55,   55,

       55,   55,  120,  119,  117,  126,   55,   89,   89,  122,
      127,   96,   96,   91,  124,  123,   91,   93,  125,   93,
       93,   55,   93,  128,   55,   55,  129,   55,   55,   55,
       55,   55,  130,  132,  138,   55,  133,   55,   55,  131,
      134,   55,  139,   55,  140,  145,  135,  136,  144,  141,
       55,  137,  142,   55,  146,   55,   55,  149,  143,   55,
      151,  147,   55,   55,  150,   55,   55,   55,   55,   55,
      152,   55,  153,   55,  156,  158,  148,   55,   55,   55,
      161,  164,   55,  163,  159,   55,  154,  155,   55,   55,
       55,   55,  157,   55,  167,   55,  160,  165,  169,   55,

      166,   55,  162,  173,  168,   55,  170,  171,  172,   55,
      174,   55,  176,   55,   55,   55,  175,   55,   55,  180,
      177,   55,   55,   55,  182,   55,  179,   55,   55,  186,
      187,  184,  181,  178,  183,   55,  185,  188,   55,   55,
      193,   55,   55,   55,  189,  194,   55,  190,  192,  191,
       55,  196,  197,   55,   55,   55,   55,   55,  198,   55,
       55,  195,  199,   55,   55,   55,  210,   55,  201,  208,
      207,   55,  200,   55,   55,  202,  203,  209,  213,  214,
       55,   55,  211,  212,  215,   55,  204,  205,  206,  216,
       55,   55,   55,   55,  225,  217,   55,  223,   55,   55,

      220,  222,  218,  219,  226,  224,   55,  227,  228,   55,
       55,   55,  221,   55,   55,  230,   55,  232,   55,   55,
      229,   55,   55,   55,  238,   55,  234,   55,  235,   55,
      237,  231,  236,   55,  233,   55,  240,  244,   55,  247,
      239,   55,   55,  241,  243,   55,   55,  245,   55,   55,
       55,  246,   55,  252,  251,  248,  249,  255,   55,   55,
      242,   55,   55,  270,  250,  264,  254,  253,  257,   55,
      256,  259,   55,  258,  260,   55,  261,  262,   55,  263,
       55,   55,  265,   55,   55,   55,   55,   55,  266,   55,
      267,  269,  271,   55,  274,   55,   55,  272,  275,   55,

      273,  278,  268,  276,  279,   55,   55,   55,   55,   55,
      281,  280,   55,  282,   55,   55,   55,   55,  287,  285,
      288,   55,   55,  283,  277,  284,  286,   55,  292,   55,
      290,  289,   55,   55,   55,  293,  291,   55,   55,   55,
       55,  294,   55,   55,  296,  297,   55,  295,  298,   55,
       55,  299,   55,  303,  300,  304,  301,   55,  305,  302,
       55,  308,   55,   55,   55,   55,   55,  309,   55,  313,
      310,  316,   55,   55,  311,   55,  318,  306,  307,   55,
      317,  312,  314,   55,  320,   55,   55,   55,  321,   55,
      323,   55,  315,  319,  322,  325,   55,   55,   55,  328,

      326,  324,   55,   55,  327,   55,  332,   55,  330,   55,
       55,  334,  331,   55,   55,   55,   55,  335,   55,  329,
      340,   55,  333,   55,  338,   55,  342,   55,  337,  339,
       55,  344,  336,   55,  341,   55,  345,   55,   55,  349,
       55,   55,   55,   55,   55,   55,  354,  343,   55,  347,
       55,   55,  346,  355,   55,  350,   55,  348,   55,  359,
       55,  357,  358,  361,  353,  351,  364,  352,  360,   55,
      356,   55,  362,  363,   55,   55,   55,   55,  365,   55,
       55,   55,  368,   55,  369,   55,   55,  366,  367,   55,
      373,  374,   55,  376,  371,  377,   55,  372,  375,  370,

       55,   55,   55,   55,  379,   55,   55,   55,   55,   55,
      382,  383,  384,   55,  390,  378,   55,  385,   55,  380,
      387,   55,  381,   55,   55,   55,  388,  386,   55,  389,
      395,  396,   55,  392,   55,   55,   55,   55,   55,  397,
      391,  394,  398,   55,   55,   55,   55,   55,   55,  393,
      399,  400,   55,   55,   55,   55,   55,  406,  559,  410,
      404,  401,  403,  408,  402,  407,  405,  411,   55,  412,
       55,  413,  409,   55,   55,   55,   55,  417,  414,   55,
       55,   55,   55,   55,  418,  419,   55,   55,  415,  426,
       55,   55,  420,  416,   55,  425,  421,  458,  422,  429,

      423,  427,   55,   55,  424,  428,   55,   55,   55,  433,
       55,  430,  431,  434,   55,  432,  435,   55,   55,  436,
       55,   55,  438,   55,   55,   55,   55,   55,   55,   55,
      442,   55,   55,   55,   55,  437,  446,   55,   55,  439,
      447,  444,  441,  440,   55,  443,  449,  445,  450,  448,
       55,  453,  454,  456,   55,  452,   55,   55,  451,  457,
       55,  459,  455,   55,   55,   55,   55,   55,   55,   55,
       55,   55,  466,  467,   55,   55,   55,   55,  469,   55,
      463,  460,  461,  462,  465,   55,  472,   55,  464,  475,
      468,  470,   55,  471,   55,  473,   55,  474,  476,   55,

       55,   55,   55,   55,   55,   55,   55,  485,   55,  483,
      477,  484,   55,   55,   55,   55,  478,  486,   55,  479,
      481,  482,   55,  491,  487,  480,   55,  489,   55,   55,
      490,   55,  488,   55,  492,  494,   55,  495,  496,   55,
      500,  493,  498,   55,  499,   55,  501,   55,   55,  497,
       55,  503,  506,   55,   55,  502,   55,   55,  507,   55,
      504,  505,   55,  511,   55,   55,   55,  512,   55,  513,
      508,  517,  509,   55,  514,  510,   55,  518,   55,  516,
      515,  519,   55,  520,   55,   55,  522,  523,  521,  525,
       55,   55,   55,  526,   55,   55,   55,  524,   55,   55,

       55,  533,   55,   55,   55,  527,   55,  528,   55,  534,
       55,  537,  529,  535,  530,  531,   55,   55,  540,   55,
      544,  538,  539,   55,  532,   55,  542,  541,  536,   55,
       55,  545,  547,   55,  543,  546,   55,   55,   55,  551,
      548,   55,  549,   55,   55,   55,  554,   55,   55,  555,
      557,   55,  560,   55,  550,   55,  553,   55,   55,  556,
       55,  562,  552,  563,   55,   55,   55,  558,   55,  564,
      567,   55,   55,  568,  572,  565,  561,  566,  569,   55,
       55,   55,   55,   55,   55,  571,  573,  576,   55,  577,
       55,   55,   55,  570,   55,  583,   55,  581,   55,  574,

      582,  578,  575,  579,   55,  580,   55,  584,   55,   55,
      586,  588,   55,  587,   55,   55,   55,   55,  589,   55,
       55,   55,  585,  590,  594,   55,  597,  598,   55,  599,
       55,  595,  596,  591,  600,   55,  592,  593,   55,   55,
      603,   55,   55,   55,  602,   55,   55,   55,   55,  606,
      607,  608,   55,   55,  610,   55,  601,  612,   55,   55,
      604,   55,  605,   55,  616,   55,   55,  613,  617,  611,
      615,  609,   55,   55,   55,   55,  618,  619,  614,   55,
      621,  623,   55,   55,  620,  622,   55,  624,  626,  627,
       55,  625,  628,   55,  629,   55,  630,   55,  631,   55,

       55,   55,   55,   55,  634,  633,   55,   55,   55,   55,
       55,   55,  638,   55,  632,   55,  643,  635,  636,  637,
       55,   55,   55,  641,  647,   55,  648,   55,   55,  640,
      642,   55,   55,   55,  639,   55,  652,  644,  645,   55,
      646,  649,  653,   55,  654,   55,  650,   55,  656,   55,
       55,  651,  657,  655,  658,   55,   55,   55,   55,   55,
      660,  661,   55,  663,  659,   55,   55,   55,   55,   55,
      664,  662,  670,   55,  665,  666,  667,  671,   55,   55,
      668,  673,   55,  672,   55,   55,  669,  674,  675,   55,
      676,   55,  677,  678,  679,   55,   55,   55,   55,   55,

      680,   55,   55,  681,   55,  682,  684,   55,   55,  689,
       55,   55,   55,  686,  683,   55,  691,   55,   55,   55,
       55,  692,  693,   55,   55,  688,  687,  685,   55,   55,
      702,   55,   55,  695,  698,  690,  694,  701,  696,   55,
       55,   55,  697,  705,   55,  699,  700,  706,   55,   55,
      703,   55,  709,   55,  710,   55,  708,   55,   55,  704,
      712,   55,  711,   55,  713,  714,   55,  707,   55,   55,
       55,  718,   55,  715,  717,   55,   55,  716,   55,  719,
      721,   55,  722,   55,  723,   55,  720,   55,  724,   55,
       55,   55,  727,  730,   55,  725,   55,   55,  726,   55,

       55,   55,   55,  728,   55,   55,   55,   55,   55,  729,
       36,   36,   36,   36,   36,   36,   41,   41,   41,   41,
       41,   41,   45,   45,   45,   45,   45,   45,   50,   50,
       50,   50,   50,   50,   58,   58,   55,   58,   58,   58,
       89,   89,   55,   55,   55,   89,   91,   91,   55,   55,
       91,   96,   96,   55,   55,   55,   96,   59,   59,   55,
       59,   59,   59,   55,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   55,   55,

       97,   95,   94,   92,   90,   55,   97,   95,   94,   92,
       90,   55,  731,   11,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731
    } ;

static yyconst flex_int16_t yy_chk[1553] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    3,
        3,    4,    4,    4,   19,    5,    5,   19,    3,    5,
       13,    4,    6,    6,   13,    5,    6,    9,    9,    9,
       40,   40,    6,    7,    7,    7,    7,    9,    7,   10,
       10,   10,   23,   23,    7,    8,    8,    8,    8,   10,
        8,   23,   16,  740,   16,   16,    8,   16,   21,   18,
       22,   18,   18,   16,   18,   20,   20,   21,   26,   27,

       29,   24,   21,   20,   22,   24,   25,   28,   28,   30,
       34,   25,   26,   27,   24,   31,   32,   27,   30,   44,
       29,   32,   44,   30,   33,   33,   81,   28,   34,   31,
       53,   53,   31,   35,   35,   32,  736,   49,   35,   49,
       49,   33,   49,   55,   81,   55,   55,   56,   55,   63,
       58,   56,   58,   58,   61,   58,   62,   61,   64,   62,
       65,   58,   66,   67,   68,   65,   63,   69,   68,   71,
       70,   72,   69,   70,   72,   64,   70,   73,   72,   66,
       67,   73,   75,   74,   76,   77,   79,   78,   80,   70,
       74,   78,   82,   71,   75,   83,   76,   84,   85,   87,

       86,  730,   80,   79,   77,   86,   88,   90,   90,   82,
       87,   97,   97,   92,   84,   83,   92,   94,   85,   94,
       94,   98,   94,   88,   99,  100,   98,  102,  101,  103,
      104,  106,   99,  101,  104,  723,  102,  105,  107,  100,
      102,  108,  105,  109,  106,  110,  102,  102,  109,  107,
      110,  103,  107,  111,  111,  112,  113,  114,  108,  115,
      116,  112,  114,  117,  115,  116,  118,  119,  120,  121,
      117,  122,  118,  123,  121,  123,  113,  124,  125,  128,
      126,  128,  129,  127,  124,  126,  119,  120,  127,  130,
      131,  133,  122,  134,  130,  132,  125,  128,  132,  136,

      129,  140,  126,  136,  131,  135,  133,  134,  135,  137,
      137,  138,  139,  141,  142,  144,  138,  139,  143,  143,
      140,  145,  147,  146,  145,  148,  142,  149,  151,  149,
      149,  147,  144,  141,  146,  152,  148,  150,  150,  153,
      154,  154,  156,  160,  151,  155,  157,  151,  153,  152,
      155,  157,  158,  159,  161,  162,  164,  158,  159,  166,
      165,  156,  160,  168,  169,  171,  167,  722,  162,  165,
      164,  167,  161,  163,  172,  163,  163,  166,  170,  170,
      173,  170,  168,  169,  171,  174,  163,  163,  163,  172,
      175,  176,  177,  178,  180,  173,  179,  178,  181,  180,

      176,  177,  174,  175,  181,  179,  182,  182,  183,  184,
      185,  186,  176,  183,  189,  185,  187,  187,  190,  191,
      184,  192,  194,  196,  195,  198,  190,  200,  191,  195,
      194,  186,  192,  205,  189,  197,  197,  199,  201,  201,
      196,  202,  199,  197,  198,  203,  204,  199,  206,  207,
      224,  200,  208,  206,  205,  202,  203,  209,  210,  212,
      197,  218,  209,  224,  204,  218,  208,  207,  211,  211,
      210,  213,  213,  212,  214,  214,  215,  216,  216,  217,
      217,  215,  219,  222,  220,  221,  223,  219,  220,  225,
      221,  223,  225,  226,  226,  227,  229,  225,  227,  228,

      225,  229,  222,  228,  230,  231,  234,  232,  233,  230,
      232,  231,  235,  233,  236,  238,  241,  237,  238,  236,
      239,  239,  242,  234,  228,  235,  237,  240,  243,  246,
      241,  240,  247,  243,  244,  244,  242,  245,  248,  252,
      254,  245,  721,  249,  247,  248,  250,  246,  249,  251,
      253,  250,  255,  254,  251,  255,  252,  256,  256,  253,
      258,  264,  261,  265,  266,  267,  264,  265,  268,  266,
      265,  269,  269,  270,  265,  271,  271,  258,  261,  272,
      270,  265,  267,  273,  273,  274,  275,  277,  274,  276,
      276,  281,  268,  272,  275,  278,  278,  279,  280,  281,

      279,  277,  282,  283,  280,  284,  285,  285,  283,  286,
      287,  287,  284,  289,  290,  291,  293,  289,  292,  282,
      294,  296,  286,  295,  292,  294,  296,  297,  291,  293,
      298,  298,  290,  299,  295,  300,  299,  301,  302,  303,
      303,  304,  305,  306,  307,  308,  308,  297,  309,  301,
      313,  310,  300,  308,  314,  304,  718,  302,  311,  311,
      312,  309,  310,  313,  307,  305,  317,  306,  312,  319,
      308,  317,  314,  315,  315,  318,  320,  321,  318,  322,
      323,  324,  321,  326,  322,  327,  328,  319,  320,  329,
      327,  328,  330,  330,  324,  331,  333,  326,  329,  323,

      331,  334,  335,  336,  334,  337,  338,  340,  343,  339,
      337,  338,  339,  341,  345,  333,  344,  340,  345,  335,
      342,  342,  336,  346,  347,  348,  343,  341,  350,  344,
      351,  352,  352,  347,  353,  351,  355,  356,  354,  353,
      346,  350,  354,  357,  358,  359,  360,  361,  362,  348,
      355,  356,  364,  366,  367,  365,  523,  362,  523,  367,
      360,  357,  359,  365,  358,  364,  361,  368,  368,  369,
      370,  370,  366,  371,  369,  372,  373,  374,  371,  375,
      383,  376,  374,  377,  375,  376,  378,  379,  372,  380,
      380,  415,  377,  373,  714,  379,  377,  415,  377,  383,

      377,  381,  381,  384,  378,  382,  382,  385,  386,  388,
      391,  384,  385,  389,  388,  386,  390,  392,  389,  391,
      394,  390,  393,  393,  395,  397,  398,  399,  400,  401,
      398,  402,  404,  403,  406,  392,  402,  405,  407,  394,
      403,  400,  397,  395,  412,  399,  405,  401,  406,  404,
      408,  409,  410,  413,  413,  408,  409,  410,  407,  414,
      414,  416,  412,  417,  418,  419,  416,  420,  421,  431,
      422,  423,  423,  424,  424,  429,  433,  430,  429,  435,
      420,  417,  418,  419,  422,  425,  432,  432,  421,  435,
      425,  430,  437,  431,  436,  433,  434,  434,  436,  439,

      440,  441,  443,  442,  444,  448,  445,  446,  446,  444,
      437,  445,  447,  449,  450,  453,  439,  447,  451,  440,
      442,  443,  454,  452,  448,  441,  455,  450,  452,  458,
      451,  459,  449,  460,  453,  455,  463,  455,  458,  464,
      461,  454,  460,  465,  460,  461,  462,  462,  466,  459,
      469,  464,  468,  470,  471,  463,  473,  468,  469,  474,
      465,  466,  475,  474,  476,  477,  478,  475,  479,  476,
      470,  480,  471,  488,  477,  473,  480,  481,  481,  479,
      478,  482,  482,  483,  483,  484,  486,  487,  484,  489,
      489,  486,  487,  490,  491,  492,  493,  488,  490,  494,

      495,  495,  496,  498,  497,  491,  500,  491,  504,  496,
      499,  499,  491,  497,  492,  493,  506,  502,  503,  505,
      507,  500,  502,  503,  494,  507,  505,  504,  498,  510,
      512,  508,  509,  712,  506,  508,  508,  509,  511,  513,
      510,  514,  511,  528,  513,  515,  516,  516,  517,  517,
      521,  522,  524,  524,  512,  521,  515,  526,  529,  517,
      527,  527,  514,  528,  530,  532,  531,  522,  535,  529,
      532,  533,  537,  533,  537,  530,  526,  531,  534,  534,
      536,  538,  539,  540,  542,  536,  538,  541,  541,  542,
      544,  545,  543,  535,  547,  548,  548,  545,  549,  539,

      547,  543,  540,  543,  550,  544,  551,  549,  552,  556,
      551,  553,  553,  552,  555,  557,  558,  559,  555,  562,
      563,  561,  550,  556,  561,  564,  564,  565,  565,  566,
      566,  562,  563,  557,  567,  567,  558,  559,  568,  570,
      571,  571,  572,  574,  570,  573,  578,  575,  581,  574,
      575,  577,  577,  579,  579,  580,  568,  581,  582,  584,
      572,  585,  573,  586,  586,  591,  594,  582,  587,  580,
      585,  578,  589,  587,  590,  592,  589,  590,  584,  593,
      592,  594,  595,  596,  591,  593,  597,  595,  597,  601,
      601,  596,  602,  602,  604,  604,  605,  606,  606,  607,

      609,  605,  610,  614,  610,  609,  611,  612,  613,  615,
      616,  617,  614,  618,  607,  619,  619,  611,  612,  613,
      620,  621,  622,  617,  623,  623,  624,  625,  626,  616,
      618,  624,  630,  631,  615,  634,  631,  620,  621,  635,
      622,  625,  632,  632,  633,  633,  626,  636,  635,  637,
      638,  630,  636,  634,  637,  639,  640,  641,  642,  643,
      639,  640,  648,  642,  638,  644,  645,  646,  649,  651,
      643,  641,  650,  650,  644,  645,  646,  651,  652,  659,
      648,  655,  655,  652,  656,  663,  649,  656,  657,  657,
      658,  658,  659,  660,  661,  661,  662,  664,  660,  665,

      662,  666,  667,  663,  668,  664,  666,  669,  671,  672,
      672,  674,  678,  668,  665,  677,  677,  680,  681,  682,
      686,  678,  680,  683,  684,  671,  669,  667,  687,  685,
      690,  690,  688,  682,  685,  674,  681,  688,  683,  691,
      692,  710,  684,  693,  693,  686,  687,  694,  694,  695,
      691,  696,  697,  697,  698,  698,  696,  699,  707,  692,
      700,  700,  699,  701,  701,  703,  703,  695,  704,  715,
      708,  711,  711,  704,  708,  713,  724,  707,  726,  713,
      716,  716,  717,  717,  719,  719,  715,  720,  720,  725,
      727,  728,  726,  729,  729,  724,  709,  706,  725,  705,

      702,  689,  679,  727,  676,  675,  673,  670,  654,  728,
      732,  732,  732,  732,  732,  732,  733,  733,  733,  733,
      733,  733,  734,  734,  734,  734,  734,  734,  735,  735,
      735,  735,  735,  735,  737,  737,  653,  737,  737,  737,
      738,  738,  647,  629,  628,  738,  739,  739,  627,  608,
      739,  741,  741,  603,  600,  599,  741,  742,  742,  598,
      742,  742,  742,  588,  583,  576,  569,  560,  554,  546,
      525,  520,  519,  518,  501,  485,  472,  467,  457,  456,
      438,  428,  427,  426,  411,  396,  387,  363,  349,  332,
      325,  316,  288,  263,  262,  260,  259,  257,  193,  188,

       96,   95,   93,   91,   89,   54,   50,   46,   45,   41,
       36,   12,   11,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "util/configlexer.lex"
#line 2 "util/configlexer.lex"
/*
 * configlexer.lex - lexical analyzer for unbound config file
 *
 * Copyright (c) 2001-2006, NLnet Labs. All rights reserved
 *
 * See LICENSE for the license.
 *
 */

#include "config.h"

#include <ctype.h>
#include <string.h>
#include <strings.h>

#include "util/configyyrename.h"
#include "util/config_file.h"
#include "util/configparser.h"
void ub_c_error(const char *message);

#define YY_NO_UNPUT

#if 0
#define LEXOUT(s)  printf s /* used ONLY when debugging */
#else
#define LEXOUT(s)
#endif

#define YDOUT LEXOUT(("v(%s )", yytext))

struct inc_state {
	char* filename;
	int line;
};
static struct inc_state parse_stack[MAXINCLUDES];
static YY_BUFFER_STATE include_stack[MAXINCLUDES];
static int config_include_stack_ptr = 0;

static void config_start_include(const char* filename)
{
	FILE *input;
	if(strlen(filename) == 0) {
		ub_c_error_msg("empty include file name");
		return;
	}
	if(config_include_stack_ptr >= MAXINCLUDES) {
		ub_c_error_msg("includes nested too deeply, skipped (>%d)", MAXINCLUDES);
		return;
	}
	input = fopen(filename, "r");
	if(!input) {
		ub_c_error_msg("cannot open include file '%s': %s",
			filename, strerror(errno));
		return;
	}
	LEXOUT(("switch_to_include_file(%s) ", filename));
	parse_stack[config_include_stack_ptr].filename = cfg_parser->filename;
	parse_stack[config_include_stack_ptr].line = cfg_parser->line;
	include_stack[config_include_stack_ptr] = YY_CURRENT_BUFFER;
	cfg_parser->filename = strdup(filename);
	cfg_parser->line = 1;
	yy_switch_to_buffer(yy_create_buffer(input,YY_BUF_SIZE));
	++config_include_stack_ptr;
}

static void config_end_include(void)
{
	--config_include_stack_ptr;
	free(cfg_parser->filename);
	cfg_parser->filename = parse_stack[config_include_stack_ptr].filename;
	cfg_parser->line = parse_stack[config_include_stack_ptr].line;
	yy_delete_buffer(YY_CURRENT_BUFFER);
	yy_switch_to_buffer(include_stack[config_include_stack_ptr]);
}

#ifndef yy_set_bol /* compat definition, for flex 2.4.6 */
#define yy_set_bol(at_bol) \
        { \
	        if ( ! yy_current_buffer ) \
	                yy_current_buffer = yy_create_buffer(yyin,YY_BUF_SIZE ); \
	        yy_current_buffer->yy_ch_buf[0] = ((at_bol)?'\n':' '); \
        }
#endif


#line 1127 "<stdout>"

#define INITIAL 0
#define quotedstring 1
#define singlequotedstr 2
#define include 3
#define include_quoted 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 99 "util/configlexer.lex"

#line 1284 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (yy_c_buf_p) - (yytext_ptr);
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 732 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1514 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 100 "util/configlexer.lex"
{ LEXOUT(("SP ")); /* ignore */ }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 101 "util/configlexer.lex"
{ LEXOUT(("comment(%s) ", yytext)); /* ignore */ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 102 "util/configlexer.lex"
{ YDOUT; return VAR_SERVER;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 103 "util/configlexer.lex"
{ YDOUT; return VAR_NUM_THREADS;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 104 "util/configlexer.lex"
{ YDOUT; return VAR_VERBOSITY;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 105 "util/configlexer.lex"
{ YDOUT; return VAR_PORT;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 106 "util/configlexer.lex"
{ YDOUT; return VAR_OUTGOING_PORT;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 107 "util/configlexer.lex"
{ YDOUT; return VAR_OUTGOING_RANGE;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 108 "util/configlexer.lex"
{ YDOUT; return VAR_OUTGOING_NUM_TCP;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 109 "util/configlexer.lex"
{ YDOUT; return VAR_INCOMING_NUM_TCP;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 110 "util/configlexer.lex"
{ YDOUT; return VAR_DO_IP4;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 111 "util/configlexer.lex"
{ YDOUT; return VAR_DO_IP6;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 112 "util/configlexer.lex"
{ YDOUT; return VAR_DO_UDP;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 113 "util/configlexer.lex"
{ YDOUT; return VAR_DO_TCP;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 114 "util/configlexer.lex"
{ YDOUT; return VAR_INTERFACE;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 115 "util/configlexer.lex"
{ YDOUT; return VAR_OUTGOING_INTERFACE;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 116 "util/configlexer.lex"
{ YDOUT; return VAR_CHROOT;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 117 "util/configlexer.lex"
{ YDOUT; return VAR_USERNAME;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 118 "util/configlexer.lex"
{ YDOUT; return VAR_DIRECTORY;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 119 "util/configlexer.lex"
{ YDOUT; return VAR_LOGFILE;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 120 "util/configlexer.lex"
{ YDOUT; return VAR_PIDFILE;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 121 "util/configlexer.lex"
{ YDOUT; return VAR_ROOT_HINTS;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 122 "util/configlexer.lex"
{ YDOUT; return VAR_MSG_BUFFER_SIZE;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 123 "util/configlexer.lex"
{ YDOUT; return VAR_MSG_CACHE_SIZE;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 124 "util/configlexer.lex"
{ YDOUT; return VAR_MSG_CACHE_SLABS;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 125 "util/configlexer.lex"
{ YDOUT; return VAR_RRSET_CACHE_SIZE;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 126 "util/configlexer.lex"
{ YDOUT; return VAR_RRSET_CACHE_SLABS;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 127 "util/configlexer.lex"
{ YDOUT; return VAR_CACHE_MAX_TTL;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 128 "util/configlexer.lex"
{ YDOUT; return VAR_INFRA_HOST_TTL;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 129 "util/configlexer.lex"
{ YDOUT; return VAR_INFRA_LAME_TTL;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 130 "util/configlexer.lex"
{ YDOUT; return VAR_INFRA_CACHE_SLABS;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 131 "util/configlexer.lex"
{ YDOUT; return VAR_INFRA_CACHE_NUMHOSTS;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 132 "util/configlexer.lex"
{ YDOUT; return VAR_INFRA_CACHE_LAME_SIZE;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 133 "util/configlexer.lex"
{ YDOUT; return VAR_NUM_QUERIES_PER_THREAD;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 134 "util/configlexer.lex"
{ YDOUT; return VAR_TARGET_FETCH_POLICY;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 135 "util/configlexer.lex"
{ YDOUT; return VAR_HARDEN_SHORT_BUFSIZE;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 136 "util/configlexer.lex"
{ YDOUT; return VAR_HARDEN_LARGE_QUERIES;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 137 "util/configlexer.lex"
{ YDOUT; return VAR_HARDEN_GLUE;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 138 "util/configlexer.lex"
{ YDOUT; return VAR_HARDEN_DNNSEC_STRIPPED;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 139 "util/configlexer.lex"
{ YDOUT; return VAR_STUB_ZONE;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 140 "util/configlexer.lex"
{ YDOUT; return VAR_NAME;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 141 "util/configlexer.lex"
{ YDOUT; return VAR_STUB_ADDR;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 142 "util/configlexer.lex"
{ YDOUT; return VAR_STUB_HOST;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 143 "util/configlexer.lex"
{ YDOUT; return VAR_FORWARD_ZONE;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 144 "util/configlexer.lex"
{ YDOUT; return VAR_FORWARD_ADDR;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 145 "util/configlexer.lex"
{ YDOUT; return VAR_FORWARD_HOST;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 146 "util/configlexer.lex"
{ YDOUT; return VAR_DO_NOT_QUERY_ADDRESS;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 147 "util/configlexer.lex"
{ YDOUT; return VAR_DO_NOT_QUERY_LOCALHOST;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 148 "util/configlexer.lex"
{ YDOUT; return VAR_ACCESS_CONTROL;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 149 "util/configlexer.lex"
{ YDOUT; return VAR_HIDE_IDENTITY;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 150 "util/configlexer.lex"
{ YDOUT; return VAR_HIDE_VERSION;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 151 "util/configlexer.lex"
{ YDOUT; return VAR_IDENTITY;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 152 "util/configlexer.lex"
{ YDOUT; return VAR_VERSION;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 153 "util/configlexer.lex"
{ YDOUT; return VAR_MODULE_CONF;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 154 "util/configlexer.lex"
{ YDOUT; return VAR_TRUST_ANCHOR_FILE;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 155 "util/configlexer.lex"
{ YDOUT; return VAR_TRUSTED_KEYS_FILE;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 156 "util/configlexer.lex"
{ YDOUT; return VAR_TRUST_ANCHOR;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 157 "util/configlexer.lex"
{ YDOUT; return VAR_VAL_OVERRIDE_DATE;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 158 "util/configlexer.lex"
{ YDOUT; return VAR_BOGUS_TTL;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 159 "util/configlexer.lex"
{ YDOUT; return VAR_VAL_CLEAN_ADDITIONAL;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 160 "util/configlexer.lex"
{ YDOUT; return VAR_VAL_PERMISSIVE_MODE;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 161 "util/configlexer.lex"
{ YDOUT; return VAR_KEY_CACHE_SIZE;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 162 "util/configlexer.lex"
{ YDOUT; return VAR_KEY_CACHE_SLABS;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 163 "util/configlexer.lex"
{ YDOUT; return VAR_VAL_NSEC3_KEYSIZE_ITERATIONS;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 164 "util/configlexer.lex"
{ YDOUT; return VAR_USE_SYSLOG;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 165 "util/configlexer.lex"
{ YDOUT; return VAR_LOCAL_ZONE;}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 166 "util/configlexer.lex"
{ YDOUT; return VAR_LOCAL_DATA;}
	YY_BREAK
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
#line 167 "util/configlexer.lex"
{ LEXOUT(("NL\n")); cfg_parser->line++;}
	YY_BREAK
/* Quoted strings. Strip leading and ending quotes */
case 69:
YY_RULE_SETUP
#line 170 "util/configlexer.lex"
{ BEGIN(quotedstring); LEXOUT(("QS ")); }
	YY_BREAK
case YY_STATE_EOF(quotedstring):
#line 171 "util/configlexer.lex"
{
        yyerror("EOF inside quoted string");
        BEGIN(INITIAL);
}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 175 "util/configlexer.lex"
{ LEXOUT(("STR(%s) ", yytext)); yymore(); }
	YY_BREAK
case 71:
/* rule 71 can match eol */
YY_RULE_SETUP
#line 176 "util/configlexer.lex"
{ cfg_parser->line++; yymore(); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 177 "util/configlexer.lex"
{
        LEXOUT(("QE "));
        BEGIN(INITIAL);
        yytext[yyleng - 1] = '\0';
	yylval.str = strdup(yytext);
	if(!yylval.str)
		yyerror("out of memory");
        return STRING;
}
	YY_BREAK
/* Single Quoted strings. Strip leading and ending quotes */
case 73:
YY_RULE_SETUP
#line 188 "util/configlexer.lex"
{ BEGIN(singlequotedstr); LEXOUT(("SQS ")); }
	YY_BREAK
case YY_STATE_EOF(singlequotedstr):
#line 189 "util/configlexer.lex"
{
        yyerror("EOF inside quoted string");
        BEGIN(INITIAL);
}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 193 "util/configlexer.lex"
{ LEXOUT(("STR(%s) ", yytext)); yymore(); }
	YY_BREAK
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
#line 194 "util/configlexer.lex"
{ cfg_parser->line++; yymore(); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 195 "util/configlexer.lex"
{
        LEXOUT(("SQE "));
        BEGIN(INITIAL);
        yytext[yyleng - 1] = '\0';
	yylval.str = strdup(yytext);
	if(!yylval.str)
		yyerror("out of memory");
        return STRING;
}
	YY_BREAK
/* include: directive */
case 77:
YY_RULE_SETUP
#line 206 "util/configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); BEGIN(include); }
	YY_BREAK
case YY_STATE_EOF(include):
#line 207 "util/configlexer.lex"
{
        yyerror("EOF inside include directive");
        BEGIN(INITIAL);
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 211 "util/configlexer.lex"
{ LEXOUT(("ISP ")); /* ignore */ }
	YY_BREAK
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
#line 212 "util/configlexer.lex"
{ LEXOUT(("NL\n")); cfg_parser->line++;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 213 "util/configlexer.lex"
{ LEXOUT(("IQS ")); BEGIN(include_quoted); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 214 "util/configlexer.lex"
{
	LEXOUT(("Iunquotedstr(%s) ", yytext));
	config_start_include(yytext);
	BEGIN(INITIAL);
}
	YY_BREAK
case YY_STATE_EOF(include_quoted):
#line 219 "util/configlexer.lex"
{
        yyerror("EOF inside quoted string");
        BEGIN(INITIAL);
}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 223 "util/configlexer.lex"
{ LEXOUT(("ISTR(%s) ", yytext)); yymore(); }
	YY_BREAK
case 83:
/* rule 83 can match eol */
YY_RULE_SETUP
#line 224 "util/configlexer.lex"
{ cfg_parser->line++; yymore(); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 225 "util/configlexer.lex"
{
	LEXOUT(("IQE "));
	yytext[yyleng - 1] = '\0';
	config_start_include(yytext);
	BEGIN(INITIAL);
}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 231 "util/configlexer.lex"
{
	yy_set_bol(1); /* Set beginning of line, so "^" rules match.  */
	if (config_include_stack_ptr == 0) {
		yyterminate();
	} else {
		fclose(yyin);
		config_end_include();
	}
}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 241 "util/configlexer.lex"
{ LEXOUT(("unquotedstr(%s) ", yytext)); 
			yylval.str = strdup(yytext); return STRING; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 244 "util/configlexer.lex"
ECHO;
	YY_BREAK
#line 1877 "<stdout>"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 732 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 732 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 731);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 244 "util/configlexer.lex"



